@@ -19,6 +19,7 @@
 # ***** END LICENSE BLOCK *****
 
 import seqdb
+import template
 
 _DB = seqdb.get()
 
@@ -68,11 +69,11 @@ def format(c, is_input, tracer, controller):
     """
       >>> _create_mock_db()
       >>> str(format(ord("a"), False, None, None)).replace("\x1b", "\\x1b")
-      "(u'\\\\x1b[32ma', False)"
+      "(u'\\\\x1b[32ma\\\\x1b[m', False)"
       >>> str(format(ord("\x1b"), False, None, None)).replace("\x1b", "\\x1b")
-      "(u'\\\\x1b[32m<ESC>', False)"
+      "('\\\\x1b[32m<ESC>\\\\x1b[m', False)"
       >>> str(format(ord("\x07"), False, None, None)).replace("\x1b", "\\x1b")
-      "(u'\\\\x1b[31m<BEL>\\\\x1b[1;32m\\\\r\\\\x1b[30CBEL / bell', True)"
+      "('\\\\x1b[31m<BEL>\\\\x1b[1;32m\\\\r\\\\x1b[30CBEL / bell\\\\x1b[m', True)"
     """
 
     if c in _CHAR_MAP:
@@ -91,9 +92,8 @@ def format(c, is_input, tracer, controller):
     if mnemonic:
         if mnemonic[0] == "!":
             return eval(mnemonic[1:])
-        template = u"\x1b[31m%s\x1b[1;32m\x0d\x1b[30C%s"
-        return template % (printable_char, mnemonic), True
-    return u"\x1b[32m%s" % printable_char, False
+        return template.getprintablechar() % (printable_char, mnemonic), True
+    return template.getchar() % printable_char, False
 
 
 def _create_mock_db():
@@ -105,6 +105,7 @@ def _create_mock_db():
         '> <BEL>': 'BEL / bell',
     }
 
+
 if __name__ == "__main__":
     import doctest
     doctest.testmod()
